@@ -28,3 +28,15 @@ class ProjectAccessController(SystemAccessController):
                 pass
             else: 
                 self.assertRoleNotAuthorised(role, "visitor's project %s role" % role.name.lower())
+
+    def makeMemoName(self, person, actionName, protectedObject):
+        # Make sure service plugin memo names are distinct between projects.
+        # Todo: Change service access control to use service object.
+        memoName = super(ProjectAccessController, self).makeMemoName(person, actionName, protectedObject)
+        if self.project:
+            projectTag = self.project.id
+        else:
+            projectTag = None
+        memoName = "Project.%s.%s" % (projectTag, memoName)
+        return memoName
+
