@@ -16,12 +16,13 @@ class ParseUrlTest(TestCase):
         self.urlPath = self.url_scheme.url_for('project.service',
                 project='annakarenina', service='example')
     
-    def testGetVisitorName(self):
+    def testIsAuthenticated(self):
         visitorName = 'visitor'
-        outName = urlpermission.getVisitorName('notauser', 'asdfghjkl')
-        self.failUnlessEqual(outName, visitorName)
-        outName = urlpermission.getVisitorName('levin', 'levin')
-        self.failUnlessEqual(outName, 'levin')
+        person = urlpermission.isAuthenticated('notauser', 'asdfghjkl')
+        self.failIf(person)
+        person = urlpermission.isAuthenticated('levin', 'levin')
+        self.failUnless(person)
+        self.failUnlessEqual(person.name, 'levin')
     
     def testGetService(self):
         service = urlpermission.getService(self.urlPath)
@@ -39,20 +40,25 @@ class ParseUrlTest(TestCase):
             self.failUnless(actionName == httpMethod[1],
                 'Failed with http method: %s' % httpMethod[0])
     
-    def testIsAllowedAccess(self):
-        out = urlpermission.isAllowedAccess('levin', self.urlPath, 'GET')
-        self.failUnless(out)
-        out = urlpermission.isAllowedAccess('natasha', self.urlPath, 'GET')
-        self.failIf(out)
+    def testIsAccessAuthorised(self):
+        person = self.registry.persons['levin']
+        out = urlpermission.isAccessAuthorised(person, self.urlPath, 'GET')
+        self.failUnless(out, "Levin can't access: %s" % self.urlPath)
+        person = self.registry.persons['natasha']
+        out = urlpermission.isAccessAuthorised(person, self.urlPath, 'GET')
+        self.failIf(out, "Natasha can access: %s" % self.urlPath)
     
-    def test_isAllowedAccess2(self):
+    def test_isAccessAuthorised2(self):
         "warandpeace allows visitor access"
         urlpath = self.url_scheme.url_for('project_service',
                 project='warandpeace', service='example')
-        out = urlpermission.isAllowedAccess('natasha', urlpath, 'GET')
+        person = self.registry.persons['natasha']
+        out = urlpermission.isAccessAuthorised(person, urlpath, 'GET')
         self.failUnless(out, 'natasha not allowed in')
-        out = urlpermission.isAllowedAccess('visitor', urlpath, 'GET')
+        person = self.registry.persons['visitor']
+        out = urlpermission.isAccessAuthorised(person, urlpath, 'GET')
         self.failUnless(out, 'visitor not allowed in')
-        out = urlpermission.isAllowedAccess('levin', urlpath, 'GET')
+        person = self.registry.persons['levin']
+        out = urlpermission.isAccessAuthorised(person, urlpath, 'GET')
         self.failUnless(out, 'levin not allowed in')
 
