@@ -1,10 +1,10 @@
 import unittest
-import kforge.apache.apacheconfigtest
+import kforge.apache.configtest
 import kforge.apache.urlpermissiontest
 
 def suite():
     suites = [
-        kforge.apache.apacheconfigtest.suite(),
+        kforge.apache.configtest.suite(),
         kforge.apache.urlpermissiontest.suite(),
     ]
     return unittest.TestSuite(suites)
