@@ -3,11 +3,7 @@ import dm.command.person
 
 import kforge.utils.mailer
 import kforge.utils.password
-from kforge.dictionarywords import SYSTEM_NAME
-from kforge.dictionarywords import SYSTEM_SERVICE_NAME
-from kforge.dictionarywords import SERVICE_EMAIL
-from kforge.dictionarywords import DOMAIN_NAME
-from kforge.dictionarywords import SMTP_HOST
+from kforge.dictionarywords import *
 
 # Todo: Extract this to general command package.
 class EmailCommand(dm.command.Command):
@@ -21,24 +17,21 @@ class EmailCommand(dm.command.Command):
 
     def dispatchEmailMessage(self, msgFrom, msgToList, msgSubject, msgBody):
         smtpHost = self.dictionary[SMTP_HOST]
-        msg = "Sending email from: %s to: %s subject: %s body: %s host: %s" % (
+        msg = "email from: %s to: %s subject: %s body: %s host: %s" % (
             repr(msgFrom), repr(msgToList), repr(msgSubject), repr(msgBody), repr(smtpHost)
         )
-        self.logger.info(msg)
-        for msgTo in msgToList:
-            if msgTo:
-                try:
-                    kforge.utils.mailer.sendmail(msgFrom, msgTo, msgSubject, msgBody, smtpHost)
-                    self.isDispatchedOK = True
-                except Exception, inst:
+        self.isDispatchedOK = False
+        if not self.dictionary[ENABLE_EMAIL_SENDING]:
+            self.logger.info("Skipping sending %s" % msg)
+        else:
+            self.logger.info("Sending %s" % msg)
+            for msgTo in msgToList:
+                if msgTo:
                     try:
-                        msg = "Couldn't send email (from: %s, to: %s, subject: %s, body: %s, host: %s): %s" % (
-                            repr(msgFrom), repr(msgToList), repr(msgSubject), repr(msgBody), repr(smtpHost),
-                            repr(inst)
-                        )
-                        self.logger.warn(msg)
+                        kforge.utils.mailer.sendmail(msgFrom, msgTo, msgSubject, msgBody, smtpHost)
+                        self.isDispatchedOK = True
                     except Exception, inst:
-                        msg = "Couldn't send email, or log error message: %s" % inst
+                        msg = "Couldn't send %s: %s" % (msg, inst)
                         self.logger.error(msg)
 
 
