@@ -151,11 +151,7 @@ class InitialiseDomainModel(InitialiseDomainModelBase):
         plugins.create('notify')
     
     def createServicePlugins(self):
-        # Only create plugins which have *no* external dependencies beyond
-        # those for base KForge system (so no trac, svn etc).
-        plugins = self.registry.plugins
-        plugins.create('www')
-        plugins.create('dav')
+        pass
     
     def createTestPlugins(self):
         plugins = self.registry.plugins
