@@ -1,5 +1,5 @@
 from dm.command import *
-import kforge.re
+import kforge.regexps
 import re
 
 class ProjectCommand(Command):
@@ -15,7 +15,7 @@ class ProjectCommand(Command):
 class ProjectCreate(DomainObjectCreate):
     "Command to create a new project."
 
-    reservedNames = re.compile('^%s$' % kforge.re.reservedProjectName)
+    reservedNames = re.compile('^%s$' % kforge.regexps.reservedProjectName)
 
     def __init__(self, name='', **kwds):
         super(ProjectCreate, self).__init__(
@@ -98,12 +98,13 @@ class ProjectPurge(ProjectCommand):
         self.commitSuccess()
 
 
+# Todo: Test for deleted projects. They were being missed.
 class AllProjectRead(ProjectRead):
     "Command to read any project, regardless of state."
 
-    def __init__(self, name):
-        super(AllProjectRead, self).__init__(name)
-        self.projects = self.registry.projects.getAll()
+    def createRegister(self):
+        register = super(AllProjectRead, self).createRegister()
+        return self.registry.projects.getAll()
 
 
 class ProjectList(ProjectCommand):
