@@ -51,6 +51,31 @@ if webkit.webkitName == 'django' and webkit.webkitVersion == '1.0':
                 raise webkit.ValidationError(message)
             return value
 
+    class SshKeyStringField(webkit.fields.RegexField):
+
+        def __init__(self, *args, **kwargs):
+            regex = '^%s$' % (kforge.regexps.sshKeyString)
+            kwargs['required'] = True
+            kwargs['regex'] = regex 
+            kwargs['widget'] = webkit.widgets.Textarea
+            super(SshKeyStringField, self).__init__(*args, **kwargs)
+
+        def clean(self, value):
+            super(SshKeyStringField, self).clean(value)
+            # Check key string is available.
+            value = value.strip()
+            publicKey = value.split(' ')[1]
+            if kforge.command.Command.registry.sshKeys.search(publicKey):
+                message = "Key has already been registered on this site."
+                raise webkit.ValidationError(message)
+            # Check key decodes from base64.
+            try:
+                publicKey.decode('base64')
+            except:
+                message = "Key does not appear to be encoded with base64."
+                raise webkit.ValidationError(message)
+            return value
+
     class ProjectNameField(webkit.fields.RegexField):
         
         def __init__(self, *args, **kwargs):
@@ -283,6 +308,73 @@ class PersonUpdateManipulator(PersonManipulator):
             )
 
 
+class SshKeyManipulator(HasManyManipulator):
+
+    def isSshKey(self, field_data, all_data):
+        pattern = re.compile('^%s$' % kforge.regexps.sshKeyString)
+        if not pattern.match(field_data):
+            msg = "Enter a valid value. "
+            raise webkit.ValidationError(msg)
+
+    def isAvailableSshKey(self, field_data, all_data):
+        keyString = all_data['keyString']
+        keyString = keyString.strip()
+        sshKeys = []
+        for sshKey in self.registry.sshKeys.findDomainObjects(keyString=keyString):
+            if sshKey.person != self.client.person:
+                if not sshKey.isConsummated:
+                    if sshKey.getDeltaSinceDateCreated().days:
+                        sshKey.delete()
+        if self.registry.sshKeys.findDomainObjects(keyString=keyString):
+            message = "Key has already been registered."
+            raise webkit.ValidationError(message)
+
+    def isBase64Encoded(self, field_data, all_data):
+        # Check key string decodes from base64.
+        keyString = all_data['keyString']
+        keyString = keyString.strip()
+        try:
+            key = keyString.split(' ')[1].decode('base64')
+        except:
+            message = "Key string does not appear to have base64 encoding."
+            raise webkit.ValidationError(message)
+
+    def clean(self):
+        if 'keyString' in self.cleaned_data:
+            keyString = self.cleaned_data['keyString']
+            keyString = keyString.strip()
+            if self.registry.sshKeys.findDomainObjects(keyString=keyString):
+                message = "Key string has already been registered on this site."
+                if 'keyString' in self._errors:
+                    self._errors['keyString'].append(msg)
+                else:
+                    self._errors['keyString'] = webkit.fields.ErrorList([msg])
+        if self._errors:
+            delattr(self, 'cleaned_data')
+        else:
+            return self.cleaned_data
+
+
+class SshKeyCreateManipulator(SshKeyManipulator):
+
+    def buildFields(self):
+        if webkit.webkitName == 'django' and webkit.webkitVersion == '1.0':
+            self.fields = webkit.SortedDict([
+                ('keyString', SshKeyStringField()),
+            ])
+        elif webkit.webkitName == 'django' and webkit.webkitVersion == '0.96':
+            self.fields = (
+                webkit.LargeTextField(
+                    field_name="keyString", 
+                    is_required=True,
+                    validator_list=[
+                        self.isSshKey,
+                        self.isAvailableSshKey,
+                    ]
+                ),
+            )
+
+
 class ProjectManipulator(DomainObjectManipulator):
 
     def isProjectName(self, field_data, all_data):
@@ -315,7 +407,7 @@ class ProjectCreateManipulator(ProjectManipulator):
             self.fields = webkit.SortedDict([
                 ('title', webkit.Field(required=True)),
                 ('name', ProjectNameField()),
-                ('licenses',webkit.MultipleChoiceField(required=True, 
+                ('licenses',webkit.MultipleChoiceField(required=False, 
                     choices=self.listRegisteredLicenses())),
                 ('description', webkit.Field(required=True, widget=webkit.widgets.Textarea)),
             ])
@@ -327,7 +419,7 @@ class ProjectCreateManipulator(ProjectManipulator):
                 ),
                 webkit.SelectMultipleField(
                     field_name="licenses", 
-                    is_required=True,
+                    is_required=False,
                     choices=self.listRegisteredLicenses(),
                     size=4,
                 ),
@@ -368,7 +460,7 @@ class ProjectUpdateManipulator(ProjectManipulator):
             licenses = self.listRegisteredLicenses()
             self.fields = webkit.SortedDict([
                 ('title', webkit.Field(required=True)),
-                ('licenses', webkit.MultipleChoiceField(required=True, choices=licenses)),
+                ('licenses', webkit.MultipleChoiceField(required=False, choices=licenses)),
                 ('description', webkit.Field(required=True, widget=webkit.widgets.Textarea)),
             ])
         elif webkit.webkitName == 'django' and webkit.webkitVersion == '0.96':
@@ -379,7 +471,7 @@ class ProjectUpdateManipulator(ProjectManipulator):
                 ),
                 webkit.SelectMultipleField(
                     field_name="licenses", 
-                    is_required=True,
+                    is_required=False,
                     choices=self.listRegisteredLicenses(),
                     size=4,
                 ),
