@@ -4,6 +4,7 @@ from kforge.django.apps.kui.views import manipulator
 from kforge.exceptions import KforgeCommandError
 import kforge.command
 import kforge.accesscontrol
+from kforge.command.emailjoinrequest import EmailJoinRequest
 
 class AbstractProjectView(AbstractClassView, KforgeView):
 
@@ -125,6 +126,12 @@ class ProjectReadView(ProjectInstanceView, AbstractReadView):
             return False
         return self.canReadProject()
 
+    def canJoinProject(self):
+        if self.session is None or self.session.person is None \
+            or self.session.person in self.project.members or self.session.person in self.project.pending_members:
+            return False
+        return True
+
 
 class ProjectUpdateView(ProjectInstanceView, AbstractUpdateView):
 
@@ -157,6 +164,32 @@ class ProjectDeleteView(ProjectInstanceView, AbstractDeleteView):
         return '/project/'
 
 
+class ProjectJoinView(ProjectInstanceView, AbstractReadView):
+
+    templatePath = 'project/join'
+
+    def canAccess(self):
+        if not self.getDomainObject() or self.session is None or self.session.person is None:
+            msg = "Non logged in person attempting to join a project"
+            self.logger.debug(msg)
+            return False
+        #We'll just add the member to the list when they view the page rather than
+        #making them click a button
+        person = self.session.person
+        project = self.getDomainObject()
+        self.logger.debug(person)
+        self.logger.debug(project)
+        memberCommand = kforge.command.PendingMemberCreate(
+            project=project, person=person
+        )
+        memberCommand.execute()
+
+        #We'll also send an e-mail to the project administrators about it
+        emailCommand = EmailJoinRequest(project, person)
+        emailCommand.execute()
+
+        return True
+
 def list(request):
     view = ProjectListView(request=request)
     return view.getResponse()
@@ -181,3 +214,7 @@ def delete(request, projectName):
     view = ProjectDeleteView(request=request, domainObjectKey=projectName)
     return view.getResponse()
 
+def join(request, projectName):
+    view = ProjectJoinView(request=request, domainObjectKey=projectName)
+    return view.getResponse()
+
