@@ -6,6 +6,8 @@ from dm.view.base import AbstractUpdateHasManyView
 from dm.view.base import AbstractDeleteHasManyView
 from kforge.django.apps.kui.views import manipulator
 from dm.webkit import webkitName, webkitVersion
+from kforge.dictionarywords import *
+from dm.view.base import HttpResponse
 
 class ServiceView(ProjectHasManyView):
 
@@ -39,6 +41,35 @@ class ServiceView(ProjectHasManyView):
             return False
         return True
         
+    def createDelayedRedirectResponse(self, transitionMsg):
+        delay = self.dictionary[APACHE_WSGI_REDIRECT_DELAY]
+        try:
+            delay = str(int(delay.strip()))
+        except:
+            delay = '0'
+        if int(delay) > 0 and self.redirectRequiresDelay():
+            # Redirect after delay to allow server to restart.
+            self.response = HttpResponse('Please wait a few moments (%ss) whilst your service is %s....' % (delay, transitionMsg))
+            self.response.status_code = 200
+            self.response['Refresh'] = '%s; url=%s' % (delay, self.redirect)
+        else:
+            super(ServiceView, self).createRedirectResponse()
+
+    def isPostManipulationAndReloadingModWsgi(self):
+        return self.isPostManipulation() and self.isReloadingModWsgi()
+
+    def isPostManipulation(self):
+        return self.getAssociationObject() and self.redirect == self.makePostManipulateLocation()
+
+    def isReloadingModWsgi(self):
+        isModWsgi = self.dictionary[APACHE_PYTHON_MODULE] == 'mod_wsgi'
+        isReloading = self.dictionary[APACHE_RELOAD_CMD] and not self.dictionary[SKIP_APACHE_RELOAD]
+        #isReloading = isReloading and 'apacheconfig' in self.registry.plugins
+        return isModWsgi and isReloading
+
+    isReloadingModWsgi = classmethod(isReloadingModWsgi)  
+    # ... just because this method is used to configure tests. :-(
+
 
 class ServiceListView(ServiceView, AbstractListHasManyView):
 
@@ -70,6 +101,16 @@ class ServiceCreateView(ServiceView, AbstractCreateHasManyView):
     def getManipulatorClass(self):
         return manipulator.ServiceCreateManipulator
 
+    # Todo: Create page template for this message, render and return as content.
+    # Todo: Implement countdown timer for page refresh.
+    # Todo: Show link to redirect (in case it doesn't work).
+    # Todo: Make the redirect time delay configurable.
+    def createRedirectResponse(self):
+        self.createDelayedRedirectResponse('created')
+
+    def redirectRequiresDelay(self):
+        return self.isPostManipulationAndReloadingModWsgi()
+
 
 class ServiceReadView(ServiceView, AbstractReadHasManyView):
 
@@ -79,10 +120,11 @@ class ServiceReadView(ServiceView, AbstractReadHasManyView):
         return self.canReadService()
 
     def getStatusMessage(self):
-        statusMsg = "No status information"
         service = self.getAssociationObject()
         if service:
             statusMsg = service.getStatusMessage()
+        else:
+            statusMsg = "Not found"
         return statusMsg
 
     def getServiceUserHelp(self):
@@ -174,6 +216,12 @@ class ServiceUpdateView(ServiceView, AbstractUpdateHasManyView):
                 'extnForm'       : form,
             })
 
+    def createRedirectResponse(self):
+        self.createDelayedRedirectResponse('updated')
+
+    def redirectRequiresDelay(self):
+        return self.isPostManipulationAndReloadingModWsgi()
+
 
 class ServiceExtnUpdateView(ServiceView, AbstractUpdateHasManyView):
 
@@ -204,6 +252,12 @@ class ServiceDeleteView(ServiceView, AbstractDeleteHasManyView):
     def canAccess(self):
         return self.canDeleteService()
 
+    def createRedirectResponse(self):
+        self.createDelayedRedirectResponse('deleted')
+
+    def redirectRequiresDelay(self):
+        return self.isPostManipulationAndReloadingModWsgi()
+
 
 def list(request, projectName=''):
     view = ServiceListView(
