@@ -5,11 +5,14 @@ from kforge.django.apps.kui.views.service import ServiceCreateView
 from kforge.django.apps.kui.views.service import ServiceReadView
 from kforge.django.apps.kui.views.service import ServiceUpdateView
 from kforge.django.apps.kui.views.service import ServiceDeleteView
+from kforge.django.apps.kui.views.service import ServiceView
 from dm.util.datastructure import MultiValueDict
 
 # Todo: Indicate whether apache restarted since service was created
 # so that the user knows whether a new service will respond.
 
+# Todo: Redirect delay for service update and delete.
+
 def suite():
     suites = [
         unittest.makeSuite(TestServiceListView),
@@ -35,6 +38,7 @@ def suite():
         unittest.makeSuite(TestServiceUpdateViewNatashaPOSTErrorInvalid),
         unittest.makeSuite(TestServiceDeleteView),
         unittest.makeSuite(TestServiceDeleteViewNatasha),
+        unittest.makeSuite(TestServiceDeleteViewNatashaPOST),
     ]
     return unittest.TestSuite(suites)
 
@@ -115,7 +119,7 @@ class TestServiceCreateViewNatashaPOSTErrorInUse(ServiceTestCase):
     viewClass = ServiceCreateView
     POST = MultiValueDict({'name': ['example'], 'plugin': ['example']})
     requiredFormErrors = "A service called 'example' already exists. Please choose another service name."
-    requiredResponseClassName = 'HttpResponse'
+    requiredResponseClassName = 'HttpResponseBadRequest'
     requiredRedirect = ''
 
 
@@ -125,7 +129,7 @@ class TestServiceCreateViewNatashaPOSTErrorRequired(ServiceTestCase):
     viewClass = ServiceCreateView
     POST = MultiValueDict({'name': [''], 'plugin': ['example']})
     requiredFormErrors = ['name', 'This field is required.']
-    requiredResponseClassName = 'HttpResponse'
+    requiredResponseClassName = 'HttpResponseBadRequest'
     requiredRedirect = ''
 
 
@@ -135,7 +139,7 @@ class TestServiceCreateViewNatashaPOSTErrorInvalid(ServiceTestCase):
     viewClass = ServiceCreateView
     POST = MultiValueDict({'name': ['/'], 'plugin': ['example']})
     requiredFormErrors = ['name', 'Enter a valid value.']
-    requiredResponseClassName = 'HttpResponse'
+    requiredResponseClassName = 'HttpResponseBadRequest'
     requiredRedirect = ''
 
 class TestServiceCreateViewNatashaPOSTErrorInUse(ServiceTestCase):
@@ -144,7 +148,7 @@ class TestServiceCreateViewNatashaPOSTErrorInUse(ServiceTestCase):
     viewClass = ServiceCreateView
     POST = MultiValueDict({'name': ['example'], 'plugin': ['example']})
     requiredFormErrors = "A service called 'example' already exists. Please choose another service name."
-    requiredResponseClassName = 'HttpResponse'
+    requiredResponseClassName = 'HttpResponseBadRequest'
     requiredRedirect = ''
 
 class TestServiceCreateViewNatashaPOST(ServiceTestCase):
@@ -153,7 +157,10 @@ class TestServiceCreateViewNatashaPOST(ServiceTestCase):
     viewClass = ServiceCreateView
     POST = MultiValueDict({'name': ['example2'], 'plugin': ['example']})
     requiredRedirect = '/project/warandpeace/services/example2/'
-    requiredResponseClassName = 'HttpResponseRedirect'
+    if ServiceView.isReloadingModWsgi():
+        requiredResponseClassName = 'HttpResponse'
+    else:
+        requiredResponseClassName = 'HttpResponseRedirect'
     requiredFormErrors = False
 
     def tearDown(self):
@@ -170,7 +177,10 @@ class TestServiceCreateViewNatashaPOSTSvn(ServiceTestCase):
     viewClass = ServiceCreateView
     POST = MultiValueDict({'name': ['svn'], 'plugin': ['svn']})
     requiredRedirect = '/project/warandpeace/services/svn/'
-    requiredResponseClassName = 'HttpResponseRedirect'
+    if ServiceView.isReloadingModWsgi():
+        requiredResponseClassName = 'HttpResponse'
+    else:
+        requiredResponseClassName = 'HttpResponseRedirect'
     requiredFormErrors = False
 
     def setUp(self):
@@ -197,7 +207,10 @@ class TestServiceCreateViewNatashaPOSTTrac(ServiceTestCase):
     viewClass = ServiceCreateView
     POST = MultiValueDict({'name': ['trac'], 'plugin': ['trac']})
     requiredRedirect = '/project/warandpeace/services/trac/edit/'
-    requiredResponseClassName = 'HttpResponseRedirect'
+    if ServiceView.isReloadingModWsgi():
+        requiredResponseClassName = 'HttpResponse'
+    else:
+        requiredResponseClassName = 'HttpResponseRedirect'
     requiredFormErrors = False
 
     def setUp(self):
@@ -262,6 +275,10 @@ class TestServiceUpdateViewNatashaPOST(ServiceTestCase):
     POST = MultiValueDict({'name': ['example3']})
     requiredRedirect = '/project/warandpeace/services/example3/'
     requiredResponseClassName = 'HttpResponseRedirect'
+    if ServiceView.isReloadingModWsgi():
+        requiredResponseClassName = 'HttpResponse'
+    else:
+        requiredResponseClassName = 'HttpResponseRedirect'
     requiredFormErrors = False
 
     def setUp(self):
@@ -489,7 +506,7 @@ class TestServiceUpdateViewNatashaPOSTErrorInUse(TestServiceUpdateViewNatashaPOS
 
     POST = MultiValueDict({'name': ['example']})
     requiredRedirect = ''
-    requiredResponseClassName = 'HttpResponse'
+    requiredResponseClassName = 'HttpResponseBadRequest'
     requiredFormErrors = "A service called 'example' already exists. Please choose another service name."
     
 
@@ -497,7 +514,7 @@ class TestServiceUpdateViewNatashaPOSTErrorRequired(TestServiceUpdateViewNatasha
 
     POST = MultiValueDict({'name': ['']})
     requiredRedirect = ''
-    requiredResponseClassName = 'HttpResponse'
+    requiredResponseClassName = 'HttpResponseBadRequest'
     requiredFormErrors = ['name', 'This field is required.']
     
 
@@ -505,7 +522,7 @@ class TestServiceUpdateViewNatashaPOSTErrorInvalid(TestServiceUpdateViewNatashaP
 
     POST = MultiValueDict({'name': [' ']})
     requiredRedirect = ''
-    requiredResponseClassName = 'HttpResponse'
+    requiredResponseClassName = 'HttpResponseBadRequest'
     requiredFormErrors = ['name', 'Enter a valid value.']
     
 
@@ -525,3 +542,30 @@ class TestServiceDeleteViewNatasha(ServiceTestCase):
     requiredRedirect = ''
     requiredResponseClassName = 'HttpResponse'
 
+
+class TestServiceDeleteViewNatashaPOST(ServiceTestCase):
+
+    viewerName = 'natasha'
+    serviceName = 'example2'
+    viewClass = ServiceDeleteView
+    POST = MultiValueDict({'Submit': ['submit']})
+    requiredRedirect = '/project/warandpeace/services/'
+    if ServiceView.isReloadingModWsgi():
+        requiredResponseClassName = 'HttpResponse'
+    else:
+        requiredResponseClassName = 'HttpResponseRedirect'
+    requiredFormErrors = False
+
+    def setUp(self):
+        if 'example2' not in self.registry.projects[self.projectName].services:
+            plugin = self.registry.plugins['example']
+            self.domainObject = self.registry.projects[self.projectName].services.create('example2', plugin=plugin)
+        super(TestServiceDeleteViewNatashaPOST, self).setUp()
+
+    def tearDown(self):
+        super(TestServiceDeleteViewNatashaPOST, self).tearDown()
+        if 'example2' in self.registry.projects[self.projectName].services:
+            service = self.registry.projects[self.projectName].services['example2']
+            service.delete()
+            service.purge()
+            self.fail("Project still has a service called 'example2'.")
