@@ -102,6 +102,23 @@ urlpatterns = patterns('kforge.django.apps.kui.views',
     (r'^person/(?P<personName>%s)/delete/$' % kforge.regexps.personName,
         'person.delete'),
 
+    #
+    ## SSH Key 
+    
+    (r'^person/(?P<personName>%s)/sshKeys/$' % kforge.regexps.personName,
+        'sshKey.list'),
+
+    (r'^person/(?P<personName>%s)/sshKeys/create/$' % kforge.regexps.personName,
+        'sshKey.create'),
+
+    (r'^person/(?P<personName>%s)/sshKeys/(?P<sshKeyId>(\d*))/delete/$' % (
+        kforge.regexps.personName),  
+        'sshKey.delete'),
+
+    (r'^person/(?P<personName>%s)/sshKeys/(?P<sshKeyId>(\d*))/$' % (
+        kforge.regexps.personName),  
+        'sshKey.read'),
+
     #
     ##  Project
 
@@ -134,6 +151,9 @@ urlpatterns = patterns('kforge.django.apps.kui.views',
         
     (r'^project/(?P<projectName>%s)/delete/$' % kforge.regexps.projectName,
         'project.delete'),
+
+    (r'^project/(?P<projectName>%s)/join/$' % kforge.regexps.projectName,
+        'project.join'),
         
 
     #
@@ -153,6 +173,14 @@ urlpatterns = patterns('kforge.django.apps.kui.views',
         kforge.regexps.projectName, kforge.regexps.personName),  
         'member.delete'),
 
+    (r'^project/(?P<projectName>%s)/members/(?P<personName>%s)/approve/$' % (
+        kforge.regexps.projectName, kforge.regexps.personName),  
+        'member.approve'),
+
+    (r'^project/(?P<projectName>%s)/members/(?P<personName>%s)/reject/$' % (
+        kforge.regexps.projectName, kforge.regexps.personName),  
+        'member.reject'),
+
     #
     ##  Service
     
@@ -177,7 +205,7 @@ urlpatterns = patterns('kforge.django.apps.kui.views',
     #
     ##  Not Found
 
-    (r'^.*$',
+    (r'^.*/$',
         'kui.pageNotFound'),
 )
 
