@@ -18,9 +18,13 @@ class ModelBuilder(dm.dom.builder.ModelBuilder):
 
     def loadPerson(self):  # Replace dm.dom.person.Person.
         from kforge.dom.person import Person
+        from kforge.dom.person import SshKey
         self.registry.registerDomainClass(Person)
+        self.registry.registerDomainClass(SshKey)
         self.registry.persons = Person.createRegister()
+        self.registry.sshKeys = SshKey.createRegister()
         Person.principalRegister = self.registry.persons
+        SshKey.principalRegister = self.registry.sshKeys
 
     def loadProject(self):
         from kforge.dom.project import Project 
@@ -48,6 +52,10 @@ class ModelBuilder(dm.dom.builder.ModelBuilder):
         self.registry.registerDomainClass(Member)
         self.registry.members = Member.createRegister()
         Member.principalRegister = self.registry.members
+        from kforge.dom.member import PendingMember
+        self.registry.registerDomainClass(PendingMember)
+        self.registry.pending_members = PendingMember.createRegister()
+        PendingMember.principalRegister = self.registry.pending_members
 
     def loadFeedEntry(self):
         from kforge.dom.feedentry import FeedEntry
