@@ -1,33 +1,34 @@
 import unittest
 from kforge.handlers.modpythontest import ModPythonHandlerTestCase
 from kforge.handlers.modpythontest import MockModPythonRequest
-from kforge.handlers.projecthost import ProjectAccessHandler
-from kforge.handlers.projecthost import ProjectAuthenHandler
+from kforge.handlers.projecthost import PythonAccessHandler
+from kforge.handlers.projecthost import PythonAuthenHandler
 from kforge.handlers.apachecodes import *
 from kforge.dictionarywords import *
 import kforge.url
 
 
+
 def suite():
     suites = [
-        unittest.makeSuite(TestProjectAccessHandler),
-        unittest.makeSuite(TestProjectAccessHandler_WithCookie),
-        unittest.makeSuite(TestProjectAuthenHandler),
+#        unittest.makeSuite(TestPythonAccessHandler),
+#        unittest.makeSuite(TestPythonAccessHandler_WithCookie),
+#        unittest.makeSuite(TestPythonAuthenHandler),
     ]
     return unittest.TestSuite(suites)
 
 
-class MockProjectAccessRequest(MockModPythonRequest):
+class MockPythonAccessRequest(MockModPythonRequest):
 
     def __init__(self):
-        super(MockProjectAccessRequest, self).__init__()
+        super(MockPythonAccessRequest, self).__init__()
         self.subprocess_env.add('HTTP_USER_AGENT', 'Mozilla')
     
 
-class TestProjectAccessHandler(ModPythonHandlerTestCase):
+class TestPythonAccessHandler(ModPythonHandlerTestCase):
 
-    requestClass = MockProjectAccessRequest
-    handlerClass = ProjectAccessHandler
+    requestClass = MockPythonAccessRequest
+    handlerClass = PythonAccessHandler
     url_scheme = kforge.url.UrlScheme()
 
     def test_isCookieClient(self):
@@ -86,10 +87,10 @@ class TestProjectAccessHandler(ModPythonHandlerTestCase):
         )
 
 
-class MockProjectAccessRequest_WithCookie(MockProjectAccessRequest):
+class MockPythonAccessRequest_WithCookie(MockPythonAccessRequest):
 
     def __init__(self):
-        super(MockProjectAccessRequest_WithCookie, self).__init__()
+        super(MockPythonAccessRequest_WithCookie, self).__init__()
         self.addSessionCookie()
 
     def addSessionCookie(self):
@@ -105,15 +106,15 @@ class MockProjectAccessRequest_WithCookie(MockProjectAccessRequest):
         self.sessionFixture = session
 
 
-class TestProjectAccessHandler_WithCookie(ModPythonHandlerTestCase):
+class TestPythonAccessHandler_WithCookie(ModPythonHandlerTestCase):
 
-    requestClass = MockProjectAccessRequest_WithCookie
-    handlerClass = ProjectAccessHandler
+    requestClass = MockPythonAccessRequest_WithCookie
+    handlerClass = PythonAccessHandler
     url_scheme = kforge.url.UrlScheme()
 
     def tearDown(self):
         self.request.sessionFixture.delete()
-        super(TestProjectAccessHandler_WithCookie, self).tearDown()
+        super(TestPythonAccessHandler_WithCookie, self).tearDown()
 
     def test_authorise_OK(self):
         self.failUnlessEqual(
@@ -148,10 +149,10 @@ class TestProjectAccessHandler_WithCookie(ModPythonHandlerTestCase):
         )
         
 
-class MockProjectAuthenRequest(MockModPythonRequest):
+class MockPythonAuthenRequest(MockModPythonRequest):
 
     def __init__(self):
-        super(MockProjectAuthenRequest, self).__init__()
+        super(MockPythonAuthenRequest, self).__init__()
         self.subprocess_env = {'HTTP_USER_AGENT': 'SVN'}
         self.user = 'admin'
         self.basicAuthPass = 'pass'
@@ -160,10 +161,10 @@ class MockProjectAuthenRequest(MockModPythonRequest):
         return self.basicAuthPass
 
 
-class TestProjectAuthenHandler(ModPythonHandlerTestCase):
+class TestPythonAuthenHandler(ModPythonHandlerTestCase):
 
-    requestClass = MockProjectAuthenRequest
-    handlerClass = ProjectAuthenHandler
+    requestClass = MockPythonAuthenRequest
+    handlerClass = PythonAuthenHandler
 
     def test_isCookieClient(self):
         self.handler.authorise()
