@@ -1,10 +1,10 @@
 import unittest
 
-import kforge.django.apps.kui.test
+import kforge.test.customer.kui
 
 def suite():
     suites = [
-        kforge.django.apps.kui.test.suite(),
+        kforge.test.customer.kui.suite(),
     ]
     return unittest.TestSuite(suites)
 
