@@ -19,8 +19,7 @@ class Plugin(kforge.plugin.base.NonServicePlugin):
     def onPersonCreate(self, person):
         if self.dictionary[DB_MIGRATION_IN_PROGRESS]:
             return
-        createObject = CreateProtectionObject(person)
-        protectionObject = createObject.create()
+        protectionObject = CreateProtectionObject(person).create()
         for permission in protectionObject.permissions:
             if not permission in person.grants:
                 person.grants.create(permission)
@@ -32,4 +31,22 @@ class Plugin(kforge.plugin.base.NonServicePlugin):
         protectionObject = findObject.find()
         if protectionObject:
             protectionObject.delete()
-            
+
+    # Todo: Fix migration, so that these protection objects and grants are created for already existing members.
+
+    def onMemberCreate(self, member):
+        if self.dictionary[DB_MIGRATION_IN_PROGRESS]:
+            return
+        protectionObject = CreateProtectionObject(member).create()
+        for permission in protectionObject.permissions:
+            if permission.action.name == 'Delete':
+                if not permission in member.person.grants:
+                    member.person.grants.create(permission)
+    
+    def onMemberPurge(self, member):
+        if self.dictionary[DB_MIGRATION_IN_PROGRESS]:
+            return
+        protectionObject = FindProtectionObject(member).find()
+        if protectionObject:
+            protectionObject.delete()
+
