@@ -1,19 +1,15 @@
 import os
 
 import kforge.plugin.base
-import kforge.apache.apacheconfig
+import kforge.apache.config
 import kforge.utils
 
 class Plugin(kforge.plugin.base.NonServicePlugin):
     
     def __init__(self, domainObject):
         super(Plugin, self).__init__(domainObject)
-        self.configBuilder = kforge.apache.apacheconfig.ApacheConfigBuilder()
+        self.configBuilder = kforge.apache.config.ApacheConfigBuilder()
     
-    def rebuildAndReload(self):
-        self.configBuilder.buildConfig()
-        self.configBuilder.reloadConfig()
-        
     def onServiceCreate(self, service):
         self.rebuildAndReload()
     
@@ -23,3 +19,7 @@ class Plugin(kforge.plugin.base.NonServicePlugin):
     def onServiceDelete(self, service):
         self.rebuildAndReload()
     
+    def rebuildAndReload(self):
+        self.configBuilder.buildAll()
+        self.configBuilder.reloadConfig()
+        
