@@ -4,6 +4,7 @@ from dm.strategy import FindProtectionObject
 from dm.strategy import CreateProtectionObject
 from dm.dictionarywords import APACHE_RELOAD_CMD
 import dm.times
+from kforge.dictionarywords import *
 
 class AbstractServicePlugin(dm.plugin.base.PluginBase):
     """
@@ -64,13 +65,11 @@ class AbstractServicePlugin(dm.plugin.base.PluginBase):
         """
         # Todo: Check at least whether HEAD gets a 404?
         if not self.dictionary[APACHE_RELOAD_CMD]:
-            msg = "Configuration created."
-            if dm.times.getUniversalNow() - service.dateCreated < 86400:
-                msg += " You may need to wait for the server to restart."
+            msg = "Created"
         elif service.isSystemUpSinceModified():
-            msg = "Running."
+            msg = "Running"
         else:
-            msg = "Waiting for new configuration to load."
+            msg = "Waiting"
         return msg
 
     def getApacheConfigCommon(self):
@@ -90,6 +89,69 @@ class AbstractServicePlugin(dm.plugin.base.PluginBase):
         """
         return ''
 
+    def buildWsgiFile(self):
+        pass
+
+    def buildCgiFile(self):
+        pass
+
+    def createWsgiScriptContent(self):
+        pythonVirtualenvActivation = self.createVirtualenvActivation()
+        if not pythonVirtualenvActivation:
+            pythonPathActivation = self.createPythonPathActivation()
+        else:
+            pythonPathActivation = ''
+        wsgiScriptBody = self.createWsgiScriptBody(pythonPathActivation)
+        wsgiScriptContent = pythonVirtualenvActivation + wsgiScriptBody
+        return wsgiScriptContent
+
+    def createWsgiScriptBody(self, pythonPathActivation):
+        raise Exception, "Method not implemented on %s" % self
+
+    def createPythonPathActivation(self):
+        pythonPathActivation = ''
+        if self.dictionary[PYTHONPATH]:
+            pythonPathActivation = """
+for path in %(PYTHON_PATH_LIST)s:
+    if path not in sys.path:
+        sys.path.append(path)
+
+"""         % {
+                'PYTHON_PATH_LIST': self.dictionary[PYTHONPATH].split(':'),
+            }
+        return pythonPathActivation
+
+    def createVirtualenvActivation(self):
+        virtualenvActivation = ''
+        if self.dictionary[VIRTUALENVBIN_PATH]:
+            # Todo: Revisit in favour of 
+            # http://code.google.com/p/modwsgi/wiki/VirtualEnvironments.
+            # would just need to know "the full path to the 'site-packages'
+            # directory for the virtual environment", but that is available 
+            # as os.path.dirname(os.__file__)? Need to baseline WSGI with
+            # WSGIPythonHome /usr/local/pythonenv/BASELINE in main Apache
+            # configuration. So would have to add that to install guides?
+            virtualenvActivation = """activate_this = '%(ACTIVATE_THIS_PATH)s'
+execfile(activate_this, dict(__file__=activate_this))
+
+"""         % {
+                'ACTIVATE_THIS_PATH': os.path.join(self.dictionary[VIRTUALENVBIN_PATH], 'activate_this.py')
+            }
+        return virtualenvActivation
+
+    # Todo: Move this to 'Filesystem'?
+    def writeFile(self, path, content, purpose):
+        path = os.path.normpath(path)
+        parent = os.path.dirname(path)
+        if not os.path.exists(parent):
+            os.makedirs(parent)
+        content = content.encode('utf-8', 'ignore')
+        # Todo: Make this filewriting safer.
+        file = open(path, 'w')
+        file.write(content)
+        file.close()
+        self.logger.info("Wrote %s on path: %s" % (purpose, path))
+
     def onServicePurge(self, service):
         if self.isOurs(service):
             self.trashServiceFolder(service)
@@ -113,7 +175,7 @@ class AbstractServicePlugin(dm.plugin.base.PluginBase):
             shutil.move(servicePath, trashNew)
         except Exception, inst:
             msg = "Couldn't move service files into trash: tried moving %s to %s: %s" % (
-                servicePath, trashNew
+                servicePath, trashNew, inst
             )
 
 
@@ -122,7 +184,7 @@ class ServicePlugin(AbstractServicePlugin):
     def getMaxServicesPerProject(self):
         return None
 
-        
+
 class SingleServicePlugin(AbstractServicePlugin):
 
     def getMaxServicesPerProject(self):
