@@ -219,8 +219,8 @@ class Plugin(kforge.plugin.base.ServicePlugin):
             import shutil
             shutil.move(servicePath, trashNew)
         except Exception, inst:
-            msg = "Couldn't move service files into trash: moving %s to %s: %s" % (
-                servicePath, trashNew
+            msg = "Couldn't move service files to trash: moving %s to %s: %s" % (
+                servicePath, trashNew, inst
             )
     
     def getApacheConfig(self, service):
@@ -228,11 +228,10 @@ class Plugin(kforge.plugin.base.ServicePlugin):
         fsPath = self.paths.getServicePath(service)
         # Todo: Figure out why this matches the "/login/ + urlPath" locations.
         return """
-        <Location %(urlPath)s>
-            
-            %(accessControl)s
-        </Location>
-        Alias %(urlPath)s """ + fsPath + """
+<Location %(urlPath)s>
+%(accessControl)s
+</Location>
+Alias %(urlPath)s """ + fsPath + """
 """
 
     def getUserHelp(self, service, serviceLocation):
