@@ -1,6 +1,8 @@
 import unittest
 import kforge.testunit
 
+from kforge.dictionarywords import *
+
 def suite():
     suites = [
         unittest.makeSuite(PluginTest),
@@ -23,6 +25,8 @@ class PluginTest(kforge.testunit.TestCase):
 
     def setUp(self):
         super(PluginTest, self).setUp()
+        self.origEmailNotifyChanges = self.dictionary[EMAIL_NOTIFY_CHANGES]
+        self.dictionary[EMAIL_NOTIFY_CHANGES] = 'on'
         self.msgStack = []
         pluginName = 'notify'
         if not self.registry.plugins.has_key(pluginName):
@@ -36,6 +40,7 @@ class PluginTest(kforge.testunit.TestCase):
 
     def tearDown(self):
         self.pluginSystem.notifyCommandClass = self.origCommandClass
+        self.dictionary[EMAIL_NOTIFY_CHANGES] = self.origEmailNotifyChanges
         super(PluginTest, self).tearDown()
    
     def failUnlessDispatched(self, *args):
