@@ -34,16 +34,13 @@ You can enable, disable, and show status in the usual way.
 [Optional] It is highly recommended that you also install the official WebAdmin trac plugin: <http://trac.edgewall.org/wiki/WebAdmin>. Full instructions can be found at that link (NB: as of trac v0.11 WebAdmin is part of trac core and therefore does not need to be separately installed).  WebAdmin allows users to administer most aspects of trac (trac specific permissions, template links, etc etc) from the web rather than needing access to the trac-admin command line utility.
 
 """
+from kforge.dictionarywords import *
 import kforge.plugin.base
 from kforge.plugin.trac.command import TracProjectEnvironmentCreate
 from kforge.plugin.trac.command import AddAdminUserCommand
 from kforge.plugin.trac.command import RemoveAdminUserCommand
 from kforge.plugin.trac.command import IsAdminUserCommand
 from kforge.plugin.trac.dom import TracProject
-from kforge.dictionarywords import TRAC_ADMIN_SCRIPT 
-from kforge.dictionarywords import TRAC_TEMPLATES_PATH
-from kforge.dictionarywords import TRAC_HTDOCS_PATH
-from kforge.dictionarywords import VIRTUALENVBIN_PATH
 import os
 import distutils.version
 import commands
@@ -67,22 +64,22 @@ class Plugin(kforge.plugin.base.ServicePlugin):
         (status, output) = commands.getstatusoutput(cmd)
         if status:
             errors.append("Couldn't find Trac admin script '%s' on path." % adminPath)
-        cmd = 'python -c "import trac; print trac.__path__[0]"'
-        (status, output) = commands.getstatusoutput(cmd)
-        if status:
+        try:
+            import trac
+        except:
             errors.append("Couldn't import Trac Python library.")
-        import trac
-        tracVersion = distutils.version.LooseVersion(trac.__version__)
-        v0_9 = distutils.version.LooseVersion('0.9')
-        v0_11 = distutils.version.LooseVersion('0.11')
-        if tracVersion <= v0_11:
-            if not self.dictionary[TRAC_TEMPLATES_PATH]:
-                errors.append("The path to Trac templates has not been set.")
-            elif not os.path.exists(self.dictionary[TRAC_TEMPLATES_PATH]):
-                errors.append("Couldn't find Trac templates folder: %s" % (self.dictionary[TRAC_TEMPLATES_PATH]))
-        if self.dictionary[TRAC_HTDOCS_PATH]:
-            if not os.path.exists(self.dictionary[TRAC_HTDOCS_PATH]):
-                errors.append("Couldn't find Trac htdocs folder: %s" % (self.dictionary[TRAC_HTDOCS_PATH]))
+        else:
+            tracVersion = distutils.version.LooseVersion(trac.__version__)
+            v0_9 = distutils.version.LooseVersion('0.9')
+            v0_11 = distutils.version.LooseVersion('0.11')
+            if tracVersion <= v0_11:
+                if not self.dictionary[TRAC_TEMPLATES_PATH]:
+                    errors.append("The path to Trac templates has not been set.")
+                elif not os.path.exists(self.dictionary[TRAC_TEMPLATES_PATH]):
+                    errors.append("Couldn't find Trac templates folder: %s" % (self.dictionary[TRAC_TEMPLATES_PATH]))
+            if self.dictionary[TRAC_HTDOCS_PATH]:
+                if not os.path.exists(self.dictionary[TRAC_HTDOCS_PATH]):
+                    errors.append("Couldn't find Trac htdocs folder: %s" % (self.dictionary[TRAC_HTDOCS_PATH]))
         return errors
 
     def showDepends(self):
@@ -218,16 +215,44 @@ class Plugin(kforge.plugin.base.ServicePlugin):
         return msg
 
     def getApacheConfigCommon(self):
-        # The htdocs path alias is implemented as an unrequired option.
-        # Todo: Decide from which version of Trac this is not needed.
-        tracHtdocsPath = self.dictionary[TRAC_HTDOCS_PATH] 
-        if tracHtdocsPath:
-            return """
-            Alias /trac %s
-            """ % tracHtdocsPath
-        else:
-            return ""
-        
+        return ""
+    
+    def buildWsgiFile(self):
+        if self.dictionary[APACHE_PYTHON_MODULE] == 'mod_wsgi':
+            wsgiScriptPath = self.dictionary[TRAC_WSGI_SCRIPT_PATH]
+            wsgiScriptContent = self.createWsgiScriptContent()
+            self.writeFile(wsgiScriptPath, wsgiScriptContent, 'Trac WSGI script')
+
+    def createWsgiScriptBody(self, pythonPathActivation):
+        wsgiScriptBody = """
+# KForge auto-generated Trac WSGI File.
+
+import os
+import sys
+
+"""
+        wsgiScriptBody += pythonPathActivation
+        wsgiScriptBody += """
+
+def application(environ, start_response):
+    os.environ['KFORGE_SETTINGS'] = '""" + self.dictionary[SYSTEM_CONFIG_PATH] + "'"
+
+        wsgiScriptBody += """
+    if 'PYTHON_EGG_CACHE' in environ:
+        os.environ['PYTHON_EGG_CACHE'] = environ['PYTHON_EGG_CACHE']
+    elif 'trac.env_path' in environ:
+        os.environ['PYTHON_EGG_CACHE'] = os.path.join(environ['trac.env_path'],
+                                                      '.egg-cache')
+    elif 'trac.env_path_parent_dir' in environ:
+        os.environ['PYTHON_EGG_CACHE'] = os.path.join(environ['trac.env_path_parent_dir'],
+                                                      '.egg-cache')
+    from kforge.handlers.modwsgi import WsgiAccessControlHandler
+    from trac.web.main import dispatch_request
+    access_control = WsgiAccessControlHandler(dispatch_request)
+    return access_control(environ, start_response)
+"""    
+        return wsgiScriptBody
+
     def getApacheConfig(self, service):
         # Todo: Don't include Apache config for Trac services that don't have an environment.
         if not service or not service.name:
@@ -237,37 +262,45 @@ class Plugin(kforge.plugin.base.ServicePlugin):
         import trac
         tracVersion = distutils.version.LooseVersion(trac.__version__)
         v0_9 = distutils.version.LooseVersion('0.9')
-       
-        if self.dictionary[VIRTUALENVBIN_PATH]:
-            tracHandlerName = 'kforgevirtualenvhandlers::trachandler'
-        else:
-            if tracVersion < v0_9:
-                tracHandlerName = 'trac.ModPythonHandler'
+        tracHtdocsPath = self.dictionary[TRAC_HTDOCS_PATH] 
+        result = '' 
+        if tracHtdocsPath:
+            result += """
+Alias %(urlPath)s/chrome """ + tracHtdocsPath + """
+"""
+        if self.dictionary[APACHE_PYTHON_MODULE] == 'mod_wsgi':
+            wsgiScriptPath = self.dictionary[TRAC_WSGI_SCRIPT_PATH]
+            result += """
+WSGIScriptAlias %(urlPath)s """ + wsgiScriptPath + """
+WSGIApplicationGroup %%{GLOBAL}
+WSGIProcessGroup """ + self.dictionary[TRAC_WSGI_PROCESS_GROUP] + """
+<Location %(urlPath)s>
+SetEnv trac.env_path %(fileSystemPath)s
+WSGIPassAuthorization On
+</Location>
+"""
+        elif self.dictionary[APACHE_PYTHON_MODULE] == 'mod_python':
+            if self.dictionary[VIRTUALENVBIN_PATH]:
+                tracHandlerName = 'kforgevirtualenvhandlers::trachandler'
             else:
-                tracHandlerName = 'trac.web.modpython_frontend'
-        result = ''
-        # Moving this to the mod_python access handler.
-        #urlBuilder = kforge.url.UrlScheme() 
-        #logoutPath = urlBuilder.url_for('logout') + '/'
-        #result += """
-        #Redirect %(urlPath)s/logout """ + logoutPath
-        #loginPath = urlBuilder.url_for('login') + '/'
-        #result += """
-        #Redirect %(urlPath)s/login """ + loginPath + """%(urlPathNoPrefix)s"""
-        result += """
-        <Location %(urlPath)s>
-          <IfModule mod_python.c>
-            SetHandler mod_python
-            PythonHandler """
-        result += tracHandlerName
-        result += """
-            PythonInterpreter main_interpreter
-            PythonOption TracEnv %(fileSystemPath)s
-            PythonOption TracUriRoot %(urlPath)s
-            
-            %(accessControl)s
-          </IfModule>
-        </Location>"""
+                if tracVersion < v0_9:
+                    tracHandlerName = 'trac.ModPythonHandler'
+                else:
+                    tracHandlerName = 'trac.web.modpython_frontend'
+            result += """
+<Location %(urlPath)s>
+<IfModule mod_python.c>
+SetHandler mod_python
+PythonHandler """
+            result += tracHandlerName
+            result += """
+PythonInterpreter main_interpreter
+PythonOption TracEnv %(fileSystemPath)s
+PythonOption TracUriRoot %(urlPath)s
+
+%(accessControl)s
+</IfModule>
+</Location>"""
         return result
     
     def backup(self, service, backupPathBuilder):
