@@ -3,8 +3,7 @@ KForge www (project home) Plugin.
 
 Enabling this plugin creates a project web directory (that is a directory on
 the file system the contents of which are displayed at the project's url on the
-KForge site). If the dav plugin is enabled then this directory will be
-accessible via dav.
+KForge site).
 
 ## Installation ##
 
@@ -19,7 +18,7 @@ import shutil
 import kforge.plugin.base
 import kforge.url
 
-class Plugin(kforge.plugin.base.SingleServicePlugin):
+class Plugin(kforge.plugin.base.ServicePlugin):
     
     def __init__(self, domainObject):
         super(Plugin, self).__init__(domainObject)
@@ -30,14 +29,14 @@ class Plugin(kforge.plugin.base.SingleServicePlugin):
         and do not need a service subdirectory
         """
         if self.isOurs(service):
-            path = self.paths.getProjectPluginPath(service.project, service.plugin)
-            self.paths.assertFolder(path, 'project services')
+            fsPath = self.paths.getServicePath(service)
+            self.paths.assertFolder(fsPath, 'project services')
     
     def getApacheConfig(self, service):
         """
         Note: allow access to everyone -- even guest
         """
-        fsPath = self.paths.getProjectPluginPath(service.project, service.plugin)
-        result = 'Alias %(urlPath)s ' + fsPath
+        fsPath = self.paths.getServicePath(service)
+        result = 'Alias %(urlPath)s ' + fsPath + '\n'
         return result
 
