@@ -1,7 +1,5 @@
 import unittest
-from kforge.testunit import ApplicationTestSuite
-
-ApplicationTestSuite.buildApplication()
+import kforge.soleInstance
 
 def run(suiteName, verbosity=1):
     suite = __import__(suiteName,'','','*').suite()
