@@ -17,6 +17,8 @@ class DatabaseTest(unittest.TestCase):
     This is why test_rebuild is commented out.
     test_init() runs last so it works
     """
+    tags = [ 'cli' ]
+    disable = True
 
     def setUp(self):
         self.db = Database()
